==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/Tree.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { TreeSelection_$type } from "./TreeSelection";
import { Direction_$type } from "./Direction";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { TreeSelectionOptionsEventArgs } from "./TreeSelectionOptionsEventArgs";
import { TreeItemComponentEventArgs } from "./TreeItemComponentEventArgs";
/**
 * @hidden
 */
export let Tree = /*@__PURE__*/ (() => {
    class Tree extends BaseElement {
        constructor() {
            super(...arguments);
            this.j = new WCNativeHelper();
            this.m = null;
            this.selectionChanged = null;
            this.itemExpanding = null;
            this.itemExpanded = null;
            this.itemCollapsing = null;
            this.itemCollapsed = null;
            this.activeItem = null;
        }
        get k() {
            return this.j;
        }
        get nativeElement() {
            return this.m;
        }
        set nativeElement(a) {
            this.m = a;
            this.j.n = this.m;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get l() {
            let ret_ = this.k.m("singleBranchExpand");
            return ret_;
        }
        set l(a) {
            let value_ = a;
            this.k.u("singleBranchExpand", value_);
        }
        get h() {
            let ret_ = this.k.m("selection");
            ret_ = enumGetBox(TreeSelection_$type, EnumUtil.getEnumValue(TreeSelection_$type, this.k.f(TreeSelection_$type, ret_)));
            return EnumUtil.getEnumValue(TreeSelection_$type, ret_);
        }
        set h(a) {
            let value_ = enumGetBox(TreeSelection_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.k.u("selection", value_);
        }
        get a() {
            let ret_ = this.k.m("dir");
            ret_ = enumGetBox(Direction_$type, EnumUtil.getEnumValue(Direction_$type, this.k.f(Direction_$type, ret_)));
            return EnumUtil.getEnumValue(Direction_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(Direction_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.k.u("dir", value_);
        }
        get b() {
            let ret_ = this.k.m("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.k.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set b(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.k.u("size", value_);
        }
        selectionChangedChanged() {
            if (this.selectionChanged != null) {
                this.k.q("selection", (a) => this.selectionChanged(this, TreeSelectionOptionsEventArgs.a(a)));
            }
            else {
                this.k.t("selection");
            }
        }
        itemExpandingChanged() {
            if (this.itemExpanding != null) {
                this.k.q("itemExpanding", (a) => this.itemExpanding(this, TreeItemComponentEventArgs.b(a)));
            }
            else {
                this.k.t("itemExpanding");
            }
        }
        itemExpandedChanged() {
            if (this.itemExpanded != null) {
                this.k.q("itemExpanded", (a) => this.itemExpanded(this, TreeItemComponentEventArgs.b(a)));
            }
            else {
                this.k.t("itemExpanded");
            }
        }
        itemCollapsingChanged() {
            if (this.itemCollapsing != null) {
                this.k.q("itemCollapsing", (a) => this.itemCollapsing(this, TreeItemComponentEventArgs.b(a)));
            }
            else {
                this.k.t("itemCollapsing");
            }
        }
        itemCollapsedChanged() {
            if (this.itemCollapsed != null) {
                this.k.q("itemCollapsed", (a) => this.itemCollapsed(this, TreeItemComponentEventArgs.b(a)));
            }
            else {
                this.k.t("itemCollapsed");
            }
        }
        activeItemChanged() {
            if (this.activeItem != null) {
                this.k.q("activeItem", (a) => this.activeItem(this, TreeItemComponentEventArgs.b(a)));
            }
            else {
                this.k.t("activeItem");
            }
        }
        p() {
            this.nativeElement.connectedCallback();
        }
        q(a) {
            this.nativeElement.expandToItem(this.k.h(a));
        }
    }
    Tree.$t = /*@__PURE__*/ markType(Tree, 'Tree', BaseElement.$);
    return Tree;
})();

==> igniteui-react-18.3.0-beta.0.tgz: package/esm2015/lib/Tree.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { TreeSelection_$type } from "./TreeSelection";
import { Direction_$type } from "./Direction";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { TreeSelectionOptionsEventArgs } from "./TreeSelectionOptionsEventArgs";
import { TreeItemComponentEventArgs } from "./TreeItemComponentEventArgs";
/**
 * @hidden
 */
export let Tree = /*@__PURE__*/ (() => {
    class Tree extends BaseElement {
        constructor() {
            super(...arguments);
            this.j = new WCNativeHelper();
            this.m = null;
            this.selectionChanged = null;
            this.itemExpanding = null;
            this.itemExpanded = null;
            this.itemCollapsing = null;
            this.itemCollapsed = null;
            this.activeItem = null;
        }
        get k() {
            return this.j;
        }
        get nativeElement() {
            return this.m;
        }
        set nativeElement(a) {
            this.m = a;
            this.j.o = this.m;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get l() {
            let ret_ = this.k.n("singleBranchExpand");
            return ret_;
        }
        set l(a) {
            let value_ = a;
            this.k.v("singleBranchExpand", value_);
        }
        get h() {
            let ret_ = this.k.n("selection");
            ret_ = enumGetBox(TreeSelection_$type, EnumUtil.getEnumValue(TreeSelection_$type, this.k.f(TreeSelection_$type, ret_)));
            return EnumUtil.getEnumValue(TreeSelection_$type, ret_);
        }
        set h(a) {
            let value_ = enumGetBox(TreeSelection_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.k.v("selection", value_);
        }
        get a() {
            let ret_ = this.k.n("dir");
            ret_ = enumGetBox(Direction_$type, EnumUtil.getEnumValue(Direction_$type, this.k.f(Direction_$type, ret_)));
            return EnumUtil.getEnumValue(Direction_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(Direction_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.k.v("dir", value_);
        }
        get b() {
            let ret_ = this.k.n("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.k.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set b(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.k.v("size", value_);
        }
        selectionChangedChanged() {
            if (this.selectionChanged != null) {
                this.k.r("selection", (a) => this.selectionChanged(this, TreeSelectionOptionsEventArgs.a(a)));
            }
            else {
                this.k.u("selection");
            }
        }
        itemExpandingChanged() {
            if (this.itemExpanding != null) {
                this.k.r("itemExpanding", (a) => this.itemExpanding(this, TreeItemComponentEventArgs.b(a)));
            }
            else {
                this.k.u("itemExpanding");
            }
        }
        itemExpandedChanged() {
            if (this.itemExpanded != null) {
                this.k.r("itemExpanded", (a) => this.itemExpanded(this, TreeItemComponentEventArgs.b(a)));
            }
            else {
                this.k.u("itemExpanded");
            }
        }
        itemCollapsingChanged() {
            if (this.itemCollapsing != null) {
                this.k.r("itemCollapsing", (a) => this.itemCollapsing(this, TreeItemComponentEventArgs.b(a)));
            }
            else {
                this.k.u("itemCollapsing");
            }
        }
        itemCollapsedChanged() {
            if (this.itemCollapsed != null) {
                this.k.r("itemCollapsed", (a) => this.itemCollapsed(this, TreeItemComponentEventArgs.b(a)));
            }
            else {
                this.k.u("itemCollapsed");
            }
        }
        activeItemChanged() {
            if (this.activeItem != null) {
                this.k.r("activeItem", (a) => this.activeItem(this, TreeItemComponentEventArgs.b(a)));
            }
            else {
                this.k.u("activeItem");
            }
        }
        p() {
            this.nativeElement.connectedCallback();
        }
        q(a) {
            this.nativeElement.expandToItem(this.k.i(a));
        }
    }
    Tree.$t = /*@__PURE__*/ markType(Tree, 'Tree', BaseElement.$);
    return Tree;
})();
